@@ -58,22 +58,22 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListTableColumnsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Paginator.ListTableColumns)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/honeycode.html#Honeycode.Paginator.ListTableColumns)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablecolumnspaginator)
     """
 
     def paginate(
-        self, *, workbookId: str, tableId: str, PaginationConfig: PaginatorConfigTypeDef = None
+        self, *, workbookId: str, tableId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListTableColumnsResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Paginator.ListTableColumns.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/honeycode.html#Honeycode.Paginator.ListTableColumns.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablecolumnspaginator)
         """
 
 
 class ListTableRowsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Paginator.ListTableRows)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/honeycode.html#Honeycode.Paginator.ListTableRows)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablerowspaginator)
     """
 
@@ -82,33 +82,33 @@ class ListTableRowsPaginator(Boto3Paginator):
         *,
         workbookId: str,
         tableId: str,
-        rowIds: Sequence[str] = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        rowIds: Sequence[str] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListTableRowsResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Paginator.ListTableRows.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/honeycode.html#Honeycode.Paginator.ListTableRows.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablerowspaginator)
         """
 
 
 class ListTablesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Paginator.ListTables)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/honeycode.html#Honeycode.Paginator.ListTables)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablespaginator)
     """
 
     def paginate(
-        self, *, workbookId: str, PaginationConfig: PaginatorConfigTypeDef = None
+        self, *, workbookId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListTablesResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Paginator.ListTables.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/honeycode.html#Honeycode.Paginator.ListTables.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablespaginator)
         """
 
 
 class QueryTableRowsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Paginator.QueryTableRows)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/honeycode.html#Honeycode.Paginator.QueryTableRows)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#querytablerowspaginator)
     """
 
@@ -118,9 +118,9 @@ class QueryTableRowsPaginator(Boto3Paginator):
         workbookId: str,
         tableId: str,
         filterFormula: "FilterTypeDef",
-        PaginationConfig: PaginatorConfigTypeDef = None
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[QueryTableRowsResultTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Paginator.QueryTableRows.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/honeycode.html#Honeycode.Paginator.QueryTableRows.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#querytablerowspaginator)
         """
